summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorMarco Lizza <[email protected]>2019-01-10 14:54:55 +0100
committerMarco Lizza <[email protected]>2019-01-10 14:54:55 +0100
commit5adcc30a2e3984d2df59e228c9360edf47f63c7a (patch)
tree4001a3296e7b6afe583d9c8506cce801ab174bae /src/raylib.h
parente48f2f9d43238293059b5c3ecec8e13eecc9a68b (diff)
downloadraylib-5adcc30a2e3984d2df59e228c9360edf47f63c7a.tar.gz
raylib-5adcc30a2e3984d2df59e228c9360edf47f63c7a.zip
Adding window visibility configuration flag.
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/raylib.h b/src/raylib.h
index 430e66db..9e254f97 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -410,8 +410,9 @@ typedef enum {
FLAG_WINDOW_RESIZABLE = 4, // Set to allow resizable window
FLAG_WINDOW_UNDECORATED = 8, // Set to disable window decoration (frame and buttons)
FLAG_WINDOW_TRANSPARENT = 16, // Set to allow transparent window
- FLAG_MSAA_4X_HINT = 32, // Set to try enabling MSAA 4X
- FLAG_VSYNC_HINT = 64 // Set to try enabling V-Sync on GPU
+ FLAG_WINDOW_HIDDEN = 32, // Set to create the window initially hidden
+ FLAG_MSAA_4X_HINT = 64, // Set to try enabling MSAA 4X
+ FLAG_VSYNC_HINT = 128 // Set to try enabling V-Sync on GPU
} ConfigFlag;
// Trace log type